import React, { useState, useEffect } from "react";
import { Form, Button, Input, Select, InputNumber, DatePicker, Upload, message } from 'antd';
import styles from "../../index.less";
import { MinusCircleOutlined, PlusOutlined, UploadOutlined, PlusCircleOutlined } from '@ant-design/icons';
import startAPI from "../../service";
import axios from 'axios';

const CouponDelivery = () => {

    const [couponInfo, SetCouponInfo] = useState([]);
    const [couponForm] = Form.useForm();
    const [imgurl, setimgUrl] = useState(null);
    const [canUseCount, setCanUseCount] = useState([]);

    /**
     * 获取优惠券列表
     */
    const onFetchCouponList = async () => {
        const response = await startAPI.GetCouponCanUseCountAndLimit();
        if (response.succeeded) {
            SetCouponInfo(response.data);
        }
    }

    const uploadProp = {
        name: 'file',
        showUploadList: false,
        multiple: false,
        accept: '.png, .jpg, .jpeg, .gif',
        // 这里需要指定文件上传的content-type
        headers: {
            'Content-Type': 'application/octet-stream',
        },
        customRequest({
            action,
            file,
            headers,
            onError,
            onProgress,
            onSuccess,
            withCredentials,
        }) {

            //覆盖action 上传之前获取上传地址
            var index = file.name.lastIndexOf(".");
            var ext = file.name.substr(index + 1);

            let fileData = null;
            startAPI.GetCosRequestURL({ directory: "activity", fileExtension: ext, method: "PUT" }).then((r) => {
                action = r.allUrl;
                var index = file.name.lastIndexOf(".");
                //获取后缀
                var ext = file.name.substr(index + 1);
                const reader = new FileReader();

                if (['png', 'jpg', 'jpeg', 'bmp', 'gif', 'webp', 'psd', 'svg', 'tiff'].indexOf(ext) == -1) {
                    message.error(`${file.name} 不是图片文件`);
                    return;
                }

                reader.readAsArrayBuffer(file);
                reader.onload = (e) => {
                    fileData = e.target.result;
                    // 使用 axios 进行文件上传的请求
                    axios.put(action, fileData, {
                        withCredentials,
                        headers,
                        onUploadProgress: ({ total, loaded }) => {
                            // 进行上传进度输出，更加直观
                            onProgress({ percent: Math.round(loaded / total * 100).toFixed(2) }, file);
                        },
                    }).then(response => {
                        couponForm.setFieldsValue({ activityImg: r.seeUrl });
                        if (response.status == 200 || response.statusText == 'OK') {
                            setimgUrl(r.seeUrl)
                        }
                    })
                        .catch(onError);
                };
            });
        },
    };

    useEffect(() => {
        onFetchCouponList();
    }, []);

    return <div className={styles.activity_form_container} >
        <Form
            form={couponForm}
            name="basic"
            labelCol={{
                span: 3,
            }}
            initialValues={{
                remember: true,
            }}
            onFinish={(values) => {
                console.log('values>>>', values);
                if (!values.activityRewards) {
                    message.error('请至少添加一种优惠券');
                    return;
                }
            }}
            layout="vertical"
            autoComplete="off"
        >
            <Form.Item
                label="活动名称"
                name="activityName"
                rules={[
                    {
                        required: true,
                        message: '请输入活动名称！',
                    },
                ]}
            >
                <Input style={{ width: '100%' }} placeholder="请输入活动名称" />
            </Form.Item>


            <Form.Item label="优惠券">
                <Form.List name="activityRewards">
                    {(fields, { add, remove }, { errors }) => (
                        <>
                            {fields.map(({ key, name, fieldKey, ...restField }) => (
                                <div className={styles.common_form_row}>
                                    <Form.Item
                                        {...restField}
                                        name={[name, 'rewardValue']}
                                        fieldKey={[fieldKey, 'rewardValue']}
                                        rules={[{ required: true, message: '请选择优惠券' }]}
                                    >
                                        <Select
                                            placeholder="请选择优惠券"
                                            style={{
                                                width: '200px',
                                            }}
                                            onChange={(value) => {
                                                const find = couponInfo.find(item => item.couponId === value);
                                                if (find) {
                                                    const temp = JSON.parse(JSON.stringify(canUseCount));
                                                    temp[key] = find;
                                                    setCanUseCount(temp);
                                                }
                                            }}
                                        >
                                            {couponInfo.map((item, index) => {
                                                return (
                                                    <Select.Option
                                                        index={index}
                                                        value={item.couponId}
                                                        key={item.couponId}
                                                    >
                                                        {item.couponName}
                                                    </Select.Option>
                                                );
                                            })}
                                        </Select>
                                    </Form.Item>

                                    <PlusCircleOutlined style={{ margin: '0 10px', flexShrink: 0, marginBottom: '24px', fontSize: '25px', color: '#F84352' }} />

                                    <div style={{ margin: '0 20px', flexShrink: 0, marginBottom: '24px', fontSize: '16px', width: '120px' }}>可领取数量: {canUseCount[key]?.canUseCount}</div>

                                    <Form.Item
                                        {...restField}
                                        name={[name, 'value']}
                                        fieldKey={[fieldKey, 'value']}
                                        rules={[
                                            {
                                                required: true,
                                                message: '请输入领取数量！',
                                            },
                                        ]}
                                    >
                                        <InputNumber placeholder="每日领取数量" style={{
                                            width: '130px',
                                        }} min={0} max={999} />
                                    </Form.Item>

                                    <MinusCircleOutlined style={{ fontSize: '25px', marginLeft: '20px', marginBottom: '24px' }} onClick={() => remove(name)} />
                                </div>
                            ))}
                            <Form.Item>
                                <Button
                                    type="dashed"
                                    onClick={() => add()}
                                    style={{
                                        width: '100%',
                                    }}
                                    icon={<PlusOutlined />}
                                >
                                    选择优惠券
                                </Button>
                                <Form.ErrorList errors={errors} />
                            </Form.Item>
                        </>
                    )}
                </Form.List>
            </Form.Item>

            <Form.Item
                name="activityStartTime"
                label="起止时间"
                rules={[{ required: true }]}
            >
                <DatePicker.RangePicker style={{ width: '100%' }} />
            </Form.Item>

            <Form.Item name="remark" label="备注" rules={[{ required: true, max: 200 }]}>
                <Input.TextArea rows={4} placeholder="请输入备注" />
            </Form.Item>

            <Form.Item name="activityRule" label="规则说明" rules={[{ required: true, max: 500 }]}>
                <Input.TextArea rows={4} placeholder="请输入规则说明" />
            </Form.Item>

            <Form.Item name="activityImg" label="活动图片" rules={[{ required: true }]}
            >
                <Upload
                    {...uploadProp}
                >
                    {imgurl ? <img src={imgurl} alt="avatar" style={{ width: '30px', height: '40px' }} /> : <Button icon={<UploadOutlined />}>上传</Button>}

                </Upload>
            </Form.Item>

            <Form.Item>
                <Button type="primary" htmlType="submit">
                    提交
                </Button>
                <Button style={{ marginLeft: '20px' }} onClick={() => {
                    couponForm.resetFields();
                    setimgUrl(null);
                }}>
                    重置
                </Button>
            </Form.Item>

        </Form>
    </div>
}

export default CouponDelivery;